@@ -316,3 +316,165 @@ class ForumAccess(models.Model):
     )
     class Meta:
         db_table = u"%sforums_access" % settings.PHPBB_TABLE_PREFIX
+
+
+class AclUser(models.Model):
+    """
+    Permission roles and/or individual permissions assigned to users
+    """
+    # user_id = models.IntegerField()
+    user = models.ForeignKey("User", blank=True,
+        # mediumint(8) unsigned
+        default=0,
+        help_text="{{fk|users|user_id}}"
+    )
+    # forum_id = models.IntegerField()
+    forum = models.ForeignKey("Forum", blank=True,
+        # mediumint(8) unsigned
+        default=0,
+        help_text="{{fk|forums|forum_id}}"
+    )
+    # auth_option_id = models.IntegerField()
+    auth_option = models.ForeignKey("AclOption", blank=True,
+        # mediumint(8) unsigned
+        default=0,
+        help_text="{{fk|acl_options|auth_option_id}}"
+    )
+    # auth_role_id = models.IntegerField()
+    auth_role = models.ForeignKey("AclRole", blank=True,
+        # mediumint(8) unsigned
+        default=0,
+        help_text="{{fk|acl_roles|role_id}}"
+    )
+    auth_setting = models.IntegerField(
+        # tinyint(2)
+        default=0,
+        help_text="ACL_YES, ACL_NO or ACL_NEVER "
+    )
+    class Meta:
+        db_table = u"%sacl_users" % settings.PHPBB_TABLE_PREFIX
+
+
+class CaptchaAnswers(models.Model):
+    """
+    is like a many-to-one model for CaptchaQuestions, but has no primary key.
+    """
+    question_id = models.IntegerField()
+    answer_text = models.CharField(max_length=255)
+    class Meta:
+        db_table = u"%scaptcha_answers" % settings.PHPBB_TABLE_PREFIX
+
+
+class ForumTrack(models.Model):
+    """
+    Unread post information is stored here
+    """
+    user = models.PositiveIntegerField(primary_key=True, db_column="user_id",
+        # mediumint(8) unsigned
+        default=0,
+        help_text="primary key"
+    )
+    forum = models.PositiveIntegerField(primary_key=True, db_column="forum_id",
+        # mediumint(8) unsigned
+        default=0,
+        help_text="primary key"
+    )
+    mark_time = models.PositiveIntegerField(
+        # int(11) unsigned
+        default=0,
+    )
+    class Meta:
+        db_table = u"%sforums_track" % settings.PHPBB_TABLE_PREFIX
+
+
+class LoginAttempt(models.Model):
+    """
+    tbd
+    """
+    attempt_ip = models.CharField(max_length=40)
+    attempt_browser = models.CharField(max_length=150)
+    attempt_forwarded_for = models.CharField(max_length=255)
+    attempt_time = models.IntegerField()
+    user_id = models.IntegerField()
+    username = models.CharField(max_length=255)
+    username_clean = models.CharField(max_length=255)
+    class Meta:
+        db_table = u"%slogin_attempts" % settings.PHPBB_TABLE_PREFIX
+
+
+class PollOption(models.Model):
+    """
+    Options text of all votes ("Yes", "No", "Maybe"...)
+    """
+    poll_option_id = models.IntegerField(
+        # tinyint(4)
+        default=0,
+    )
+    topic = models.ForeignKey("Topic", blank=True,
+        # mediumint(8) unsigned
+        default=0,
+    )
+    poll_option_text = models.TextField(
+        # text
+    )
+    poll_option_total = models.PositiveIntegerField(
+        # mediumint(8) unsigned
+        default=0,
+    )
+    class Meta:
+        db_table = u"%spoll_options" % settings.PHPBB_TABLE_PREFIX
+
+
+class QaConfirm(models.Model):
+    session_id = models.CharField(max_length=96)
+    confirm_id = models.CharField(max_length=96)
+    lang_iso = models.CharField(max_length=30)
+    question_id = models.IntegerField()
+    attempts = models.IntegerField()
+    confirm_type = models.IntegerField()
+    class Meta:
+        db_table = u"%sqa_confirm" % settings.PHPBB_TABLE_PREFIX
+
+
+class SearchWordmatch(models.Model):
+    """
+    Associate a post with indexed words
+    """
+    post_id = models.PositiveIntegerField(
+        # mediumint(8) unsigned
+        default=0,
+    )
+    word_id = models.PositiveIntegerField(
+        # mediumint(8) unsigned
+        default=0,
+    )
+    title_match = models.PositiveSmallIntegerField(unique=True,
+        # tinyint(1) unsigned
+        default=0,
+    )
+    class Meta:
+        db_table = u"%ssearch_wordmatch" % settings.PHPBB_TABLE_PREFIX
+
+
+class TopicPosted(models.Model):
+    """
+    Who posted to which topic (used for the small dots in viewforum)
+    """
+    # FIXME: ForeignKey to User?
+    id = models.PositiveIntegerField(primary_key=True, db_column="user_id",
+        # mediumint(8) unsigned
+        default=0,
+        help_text="primary key"
+    )
+    # FIXME: ForeignKey to Topic?
+    id = models.PositiveIntegerField(primary_key=True, db_column="topic_id",
+        # mediumint(8) unsigned
+        default=0,
+        help_text="primary key"
+    )
+    topic_posted = models.PositiveSmallIntegerField(
+        # tinyint(1) unsigned
+        default=0,
+    )
+    class Meta:
+        db_table = u"%stopics_posted" % settings.PHPBB_TABLE_PREFIX
